@@ -21,17 +21,16 @@ class _NoNewLine(logging.StreamHandler):
         self.flush()
 
 
-logger = logging.getLogger()
-logger.setLevel(logging.INFO)
-handler = _NoNewLine()
-handler.setFormatter(logging.Formatter("%(message)s"))
-logger.addHandler(handler)
-
-
 class Bootstrapper:
-    def __init__(self, language: str, branch: str = "3.12") -> None:
+    def __init__(
+        self,
+        language: str,
+        branch: str = "3.12",
+        logger: logging.Logger = logging.getLogger(),
+    ) -> None:
         self.language = language
         self.branch = branch
+        self.logger = logger
         self.translation_repo = f"python-docs-{self.language}"
         self.cpython_repo = f"{self.translation_repo}/venv/cpython"
         self.readme_url = "https://raw.githubusercontent.com/egeakman/python-docs-bootstrapper/master/bootstrapper/data/README.md"
@@ -43,36 +42,36 @@ class Bootstrapper:
             return response.read().decode()
 
     def create_dirs(self) -> None:
-        logger.info("Creating directories...")
+        self.logger.info("Creating directories...")
         os.makedirs(self.translation_repo, exist_ok=True)
         os.makedirs(self.cpython_repo, exist_ok=True)
-        print("✅")
+        self.logger.info("✅\n")
 
     def setup_cpython_repo(self) -> None:
         if not os.path.exists(f"{self.cpython_repo}/.git") and not os.path.isdir(
             f"{self.cpython_repo}/.git"
         ):
-            logger.info("Cloning CPython repo...")
+            self.logger.info("Cloning CPython repo...")
             subprocess.run(
                 [
                     "git",
                     "clone",
                     "https://github.com/python/cpython.git",
                     self.cpython_repo,
+                    f"--branch={self.branch}",
                     "-q",
                 ],
                 check=True,
             )
-            print("✅")
+            self.logger.info("✅\n")
 
-        subprocess.run(
-            ["git", "-C", self.cpython_repo, "checkout", self.branch, "-q"], check=True
-        )
+        self.logger.info("Updating CPython repo...")
         subprocess.run(
             ["git", "-C", self.cpython_repo, "pull", "--ff-only", "-q"], check=True
         )
+        self.logger.info("✅\n")
 
-        logger.info("Building gettext files...")
+        self.logger.info("Building gettext files...")
         subprocess.run(
             [
                 "sphinx-build",
@@ -85,21 +84,18 @@ class Bootstrapper:
             cwd=self.cpython_repo,
             check=True,
         )
-        print("✅")
+        self.logger.info("✅\n")
 
     def setup_translation_repo(self) -> None:
-        logger.info("Initializing translation repo...")
+        self.logger.info("Initializing translation repo...")
         subprocess.run(["git", "init", "-q"], cwd=self.translation_repo, check=True)
         subprocess.run(
             ["git", "branch", "-m", self.branch], cwd=self.translation_repo, check=True
         )
-        print("✅")
-
-        logger.info("Copying gettext files...")
-        files = glob.glob(f"{self.cpython_repo}/pot/**/*.pot") + glob.glob(
-            f"{self.cpython_repo}/pot/*.pot"
-        )
+        self.logger.info("✅\n")
 
+        self.logger.info("Copying gettext files...")
+        files = glob.glob(f"{self.cpython_repo}/pot/**/*.pot", recursive=True)
         files = [path.replace("\\", "/") for path in files]
 
         for file in files:
@@ -108,69 +104,62 @@ class Bootstrapper:
                     ".pot", ".po"
                 )
             )
-
-            if len(file.split("/")) > 5:
-                os.makedirs("/".join(dest_path.split("/")[:2]), exist_ok=True)
-
+            os.makedirs(os.path.dirname(dest_path), exist_ok=True)
             shutil.copyfile(file, dest_path)
             files[files.index(file)] = dest_path
-        print("✅")
+        self.logger.info("✅\n")
 
-        logger.info("Cleaning up gettext files...")
+        self.logger.info("Cleaning up gettext files...")
         for file in files:
             with open(file, "r", encoding="utf-8") as f:
                 contents = f.read()
                 contents = re.sub("^#: .*Doc/", "#: ", contents, flags=re.M)
             with open(file, "w", encoding="utf-8") as f:
                 f.write(contents)
-        print("✅")
+        self.logger.info("✅\n")
 
     def create_readme(self) -> None:
-        logger.info("Creating README.md...")
+        self.logger.info("Creating README.md...")
         try:
             readme = self._request(self.readme_url)
         except (urllib.error.HTTPError, urllib.error.URLError):
-            logger.warning(
+            self.logger.warning(
                 "\n ⚠️ Failed to fetch README.md from GitHub, using local copy..."
             )
             readme = Path(f"{os.path.dirname(__file__)}/data/README.md").read_text(
                 encoding="utf-8"
             )
-
         readme = readme.replace("{{translation.language}}", self.language)
-
         with open(f"{self.translation_repo}/README.md", "w", encoding="utf-8") as f:
             f.write(readme)
-        print("✅")
+        self.logger.info("✅\n")
 
     def create_gitignore(self) -> None:
-        logger.info("Creating .gitignore...")
+        self.logger.info("Creating .gitignore...")
         try:
             gitignore = self._request(self.gitignore_url)
         except (urllib.error.HTTPError, urllib.error.URLError):
-            logger.warning(
+            self.logger.warning(
                 "\n ⚠️ Failed to fetch .gitignore from GitHub, using local copy..."
             )
             gitignore = Path(f"{os.path.dirname(__file__)}/data/.gitignore").read_text(
                 encoding="utf-8"
             )
-
         with open(f"{self.translation_repo}/.gitignore", "w", encoding="utf-8") as f:
             f.write(gitignore)
-        print("✅")
+        self.logger.info("✅\n")
 
     def create_makefile(self) -> None:
-        logging.info("Creating .makefile...")
+        logging.info("Creating Makefile...")
         try:
             makefile = self._request(self.makefile_url)
         except (urllib.error.HTTPError, urllib.error.URLError):
-            logger.warning(
+            self.logger.warning(
                 "\n ⚠️ Failed to fetch Makefile from GitHub, using local copy..."
             )
             makefile = Path(f"{os.path.dirname(__file__)}/data/Makefile").read_text(
                 encoding="utf-8"
             )
-
         head = (
             subprocess.run(
                 ["git", "-C", self.cpython_repo, "rev-parse", "HEAD"],
@@ -180,14 +169,12 @@ class Bootstrapper:
             .stdout.strip()
             .decode()
         )
-
         makefile = makefile.replace("{{translation.language}}", self.language)
         makefile = makefile.replace("{{translation.branch}}", self.branch)
         makefile = makefile.replace("{{translation.head}}", head)
-
         with open(f"{self.translation_repo}/Makefile", "w", encoding="utf-8") as f:
             f.write(makefile)
-        print("✅")
+        self.logger.info("✅\n")
 
     def run(self) -> None:
         try:
@@ -197,9 +184,11 @@ class Bootstrapper:
             self.create_readme()
             self.create_gitignore()
             self.create_makefile()
-            logger.info(f"🎉 Done bootstrapping the {self.language} translation ✅\n")
+            self.logger.info(
+                f"🎉 Done bootstrapping the {self.language} translation ✅\n"
+            )
         except Exception as e:
-            logger.critical(
+            self.logger.critical(
                 f"❌ Bootstrapping of the {self.language} translation failed: {e}\n"
             )
             sys.exit(1)
@@ -218,6 +207,11 @@ def main() -> None:
         "-b", "--branch", type=str, default="3.12", help="CPython branch (e.g. 3.12)"
     )
     args = parser.parse_args()
+    logger = logging.getLogger()
+    logger.setLevel(logging.INFO)
+    handler = _NoNewLine()
+    handler.setFormatter(logging.Formatter("%(message)s"))
+    logger.addHandler(handler)
     Bootstrapper(args.language.lower().replace("_", "-"), args.branch).run()
 
 
